@@ -11,15 +11,14 @@ alfa.reg <- function(y, x, a, xnew = NULL, yb = NULL, seb = FALSE) {
   ## x is the independent variables
   ## a is the value of alpha
   ## internal function for the alfa-regression
-  reg <- function(para, ya, x, ha, n, px, d, D) {
+  reg <- function(para, ya, x, a, ha, d, D) {
     be <- matrix(para, ncol = d)
     mu1 <- cbind( 1, exp(x %*% be) )
     zz <- mu1^a
     ta <- rowSums(zz)
     za <- zz / ta
     ma <- ( D / a * za - 1/a ) %*% ha
-    sa <- crossprod(ya - ma) / (n - px)
-    det(sa, log = TRUE)
+    - 2 * sum( diag( crossprod(ya, ma) ) ) + sum( diag( crossprod(ma) ) )
   }
 
   if ( is.null(yb) ) {
@@ -29,8 +28,6 @@ alfa.reg <- function(y, x, a, xnew = NULL, yb = NULL, seb = FALSE) {
 
   D <- dim(y)[2]
   d <- D - 1  ## dimensionality of the simplex
-  dm <- dim(x)
-  p <- dm[2]    ;    n <- dm[1]
 
   if ( a == 0 ) {
     mod <- Compositional::comp.reg(y, x[, -1], yb = yb)
@@ -43,12 +40,12 @@ alfa.reg <- function(y, x, a, xnew = NULL, yb = NULL, seb = FALSE) {
 
     ha <- t( helm(D) )
     ini <- as.vector( solve(crossprod(x), crossprod(x, ya) ) )
-    qa1 <- nlminb( ini, reg, ya = ya, x = x, ha = ha, n = n, px = p, d = d, D = D, control = list(iter.max = 2000) )
-    qa1 <- optim( qa1$par, reg, ya = ya, x = x, ha = ha, n = n, px = p, d = d, D = D, control = list(maxit = 5000) )
-    qa2 <- optim( qa1$par, reg, ya = ya, x = x, ha = ha, n = n, px = p, d = d, D = D, control = list(maxit = 5000) )
+    qa1 <- nlminb( ini, reg, ya = ya, x = x, a = a, ha = ha, d = d, D = D, control = list(iter.max = 5000) )
+    qa1 <- optim( qa1$par, reg, ya = ya, x = x, a = a, ha = ha, d = d, D = D, control = list(maxit = 5000) )
+    qa2 <- optim( qa1$par, reg, ya = ya, x = x, a = a, ha = ha, d = d, D = D, control = list(maxit = 5000) )
     while (qa1$value - qa2$value > 1e-04) {
       qa1 <- qa2
-      qa2 <- optim( qa1$par, reg, ya = ya, x = x, ha = ha, n = n, px = p, d = d, D = D, control = list(maxit = 5000), hessian = TRUE )
+      qa2 <- optim( qa1$par, reg, ya = ya, x = x, a = a, ha = ha, d = d, D = D, control = list(maxit = 5000), hessian = TRUE )
     }
     be <- matrix(qa2$par, ncol = d)
     runtime <- proc.time() - runtime
@@ -63,7 +60,7 @@ alfa.reg <- function(y, x, a, xnew = NULL, yb = NULL, seb = FALSE) {
   if ( !is.null(xnew) ) {
     xnew <- model.matrix(~., data.frame(xnew) )
     est <- cbind( 1, exp(xnew %*% be) )
-	  est <- est/Rfast::rowsums(est)
+    est <- est/Rfast::rowsums(est)
   }
 
   if ( is.null( colnames(x) ) ) {
@@ -77,22 +74,3 @@ alfa.reg <- function(y, x, a, xnew = NULL, yb = NULL, seb = FALSE) {
 
   list(runtime = runtime, be = be, seb = seb, est = est)
 }
-
-
-
-
-
-### old reg function
-##  reg <- function(para, ya, x, d, n, D) {
-##    be <- matrix(para, ncol = d)
-##    mu1 <- cbind( 1, exp(x %*% be) )
-##    zz <- mu1^a
-##    ta <- rowSums(zz)
-##    za <- zz / ta
-##    za <- D / a * za - 1/a
-##    ma <- za %*% ha
-##    esa <- ya - ma
-##    sa <- crossprod(esa) / (n - p)
-##    su <- solve(sa)
-##    n/2 * log(det(sa)) + 0.5 * sum(esa %*% su * esa)
-##  }
